==> haskell-sourcemap-0.1.6-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-Jx2eRW10tsVBm10lnQjnKJ
key: sourcemap-0.1.6-Jx2eRW10tsVBm10lnQjnKJ
license: BSD3
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
author: Chris Done
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
abi: 17fb83e13685c197c17357690e0aff35
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-Jx2eRW10tsVBm10lnQjnKJ
depends:
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    bytestring-0.10.8.1 process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-8dFCtxgalWIN0EZXM6Nnj
key: sourcemap-0.1.6-8dFCtxgalWIN0EZXM6Nnj
license: BSD3
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
author: Chris Done
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
abi: 4f7d7209c7ffee65cdf2081a9ab4ce15
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-8dFCtxgalWIN0EZXM6Nnj
depends:
    aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    bytestring-0.10.8.1 process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
